@@ -231,9 +231,7 @@ To delete a spreadsheet, use L<Net::Google::DocumentsList>.
 
 =head1 SEE ALSO
 
-L<http://code.google.com/intl/en/apis/spreadsheets/docs/3.0/developers_guide_protocol.html>
-
-L<http://code.google.com/intl/en/apis/spreadsheets/docs/3.0/reference.html>
+L<https://developers.google.com/google-apps/spreadsheets/>
 
 L<Net::Google::AuthSub>
 
@@ -247,6 +245,6 @@ L<Net::Google::DocumentsList>
 
 =head1 AUTHOR
 
-Nobuo Danjou E<lt>nobuo.danjou@gmail.comE<gt>
+Nobuo Danjou E<lt>danjou@soffritto.orgE<gt>
 
 =cut
